#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 19/12/2007
#
#package			: alien blaster
#homepage			: http://www.schwardtnet.de/alienblaster/
#source location	: http://www.schwardtnet.de/alienblaster/archives/alienblaster-1.1.0.tgz
#dependency         : SDL 

softname='alienblaster'
softversion='1.1.0'
packageversion='50.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname"
srcpkg="$buildir/$softname-$softversion.tgz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.schwardtnet.de/alienblaster/archives/$softname-$softversion.tgz
#sourceicon=http://www.thebbps.com/blog/wp-content/uploads/2007/03/150px-alienhominid.jpg

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/alienblaster
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
            |-----handy-ruler------------------------------------------------------|
alienblaster: alienblaster - an shoot'em up where you have to kill all the aliens
alienblaster:
alienblaster: Your mission is simple: stop the invasion of the aliens and 
alienblaster: blast them!
alienblaster: 
alienblaster: 
alienblaster: 
alienblaster:
alienblaster:
alienblaster:
alienblaster:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tgz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xzvf $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
make $numjobs DESTDIR=$dest

#
# installer le package dans son répertoire de destination
#
cp -R -v sound  $dest/usr/share/alienblaster
cp -R -v images  $dest/usr/share/alienblaster
cp -R -v cfg  $dest/usr/share/alienblaster
cp -R -v src  $dest/usr/share/alienblaster
rm $dest/usr/share/alienblaster/src/*.cc

cp alienBlaster $dest/usr/share/alienblaster

#
# "faire" icon
#
#wget -c $sourceicon
#mv 150px-alienhominid.jpg alienblaster.jpg
#convert alienblaster.jpg -resize 48x48 alienblaster.png 
cp ../alienblaster.png $dest/usr/share/icons/hicolor/48x48/apps/

# "faire" .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Alien Blaster
Comment=an shoot'em up where you have to kill all the aliens
Comment[fr]=Exterminez tous les aliens
Exec=alienblaster
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Icon=alienblaster
EOF

cat <<EOF > $dest/usr/bin/alienblaster
#!/bin/sh
cd /usr/share/alienblaster
exec /usr/share/alienblaster/alienBlaster "\$@"
EOF

chmod 755 $dest/usr/bin/alienblaster

#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS  INSTALL README LICENSE CHANGELOG VERSION\
      $dest/usr/doc/$softname-$softversion
	
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp alienblaster.png $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "cxxlibs,directfb,gcc,sdl,xorg-libs,xorg-xcb,zlib" > $package.dep

#
# supprimer source
#
rm -rf $src
rm -rf $dest
